@@ -65,7 +65,7 @@ class Demo(Style):
         Create a return a frame containing themed widgets
         """
         tab = ttk.Frame(self.nb, padding=10)
-        colors = ['Primary', 'Secondary', 'Success', 'Info', 'Warning', 'Danger']
+        colors = ['Primary', 'Secondary', 'Success', 'Info', 'Warning', 'Danger', 'Light', 'Dark']
 
         header_frame = ttk.Frame(tab, padding=10)
         header = ttk.Label(header_frame, textvariable=self.theme_name, font='-size 30')
